@@ -393,8 +393,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
         dynfmt_url_template = url_template.to_string();
         // first, get the fields used in the url template
-        let (safe_headers, _) =
-            util::safe_header_names(&str_headers, false, false, &Vec::new(), "");
+        let (safe_headers, _) = util::safe_header_names(&str_headers, false, false, None, "");
         let formatstr_re: &'static Regex = regex_once_cell!(r"\{(?P<key>\w+)?\}");
         for format_fields in formatstr_re.captures_iter(url_template) {
             dynfmt_fields.push(format_fields.name("key").unwrap().as_str());
