@@ -1,16 +1,4 @@
-use std::fs;
-use std::io;
-use std::path::Path;
-
-use threadpool::ThreadPool;
-
-use crate::config::{Config, Delimiter};
-use crate::index::Indexed;
-use crate::util::{self, FilenameTemplate};
-use crate::CliResult;
-use serde::Deserialize;
-
-static USAGE: &str = "
+static USAGE: &str = r#"
 Splits the given CSV data into chunks.
 
 The files are written to the directory given with the name '{start}.csv',
@@ -23,7 +11,7 @@ Usage:
 split options:
     -s, --size <arg>       The number of records to write into each chunk.
                            [default: 500]
-    -j, --jobs <arg>       The number of spliting jobs to run in parallel.
+    -j, --jobs <arg>       The number of splitting jobs to run in parallel.
                            This only works when the given CSV data has
                            an index already created. Note that a file handle
                            is opened for each job.
@@ -45,18 +33,30 @@ Common options:
                            appear in all chunks as the header row.
     -d, --delimiter <arg>  The field delimiter for reading CSV data.
                            Must be a single character. (default: ,)
-";
+"#;
+
+use std::{fs, io, path::Path};
+
+use serde::Deserialize;
+use threadpool::ThreadPool;
+
+use crate::{
+    config::{Config, Delimiter},
+    index::Indexed,
+    util::{self, FilenameTemplate},
+    CliResult,
+};
 
 #[derive(Clone, Deserialize)]
 struct Args {
-    arg_input: Option<String>,
-    arg_outdir: String,
-    flag_size: usize,
-    flag_jobs: Option<usize>,
-    flag_filename: FilenameTemplate,
-    flag_pad: usize,
+    arg_input:       Option<String>,
+    arg_outdir:      String,
+    flag_size:       usize,
+    flag_jobs:       Option<usize>,
+    flag_filename:   FilenameTemplate,
+    flag_pad:        usize,
     flag_no_headers: bool,
-    flag_delimiter: Option<Delimiter>,
+    flag_delimiter:  Option<Delimiter>,
 }
 
 pub fn run(argv: &[&str]) -> CliResult<()> {
@@ -93,6 +93,7 @@ impl Args {
         Ok(())
     }
 
+    #[allow(clippy::unnecessary_wraps)]
     fn parallel_split(&self, idx: &Indexed<fs::File, fs::File>) -> CliResult<()> {
         let nchunks = util::num_of_chunks(idx.count() as usize, self.flag_size);
         let pool = ThreadPool::new(util::njobs(self.flag_jobs));
@@ -125,11 +126,7 @@ impl Args {
         width: usize,
     ) -> CliResult<csv::Writer<Box<dyn io::Write + 'static>>> {
         let dir = Path::new(&self.arg_outdir);
-        let path = dir.join(self.flag_filename.filename(&format!(
-            "{:0>width$}",
-            start,
-            width = width
-        )));
+        let path = dir.join(self.flag_filename.filename(&format!("{start:0>width$}")));
         let spath = Some(path.display().to_string());
         let mut wtr = Config::new(&spath).writer()?;
         if !self.rconfig().no_headers {
@@ -140,6 +137,7 @@ impl Args {
 
     fn rconfig(&self) -> Config {
         Config::new(&self.arg_input)
+            .checkutf8(false)
             .delimiter(self.flag_delimiter)
             .no_headers(self.flag_no_headers)
     }
