@@ -160,7 +160,7 @@ impl ops::DerefMut for CsvRecord {
 impl fmt::Debug for CsvRecord {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         let bytes: Vec<_> = self.iter().map(std::string::String::as_bytes).collect();
-        write!(f, "{:?}", bytes)
+        write!(f, "{bytes:?}")
     }
 }
 
